@@ -1,4 +1,7 @@
-def testModule(moduleName):
+import os
+from .downloader import download, update
+
+def testModule(moduleName, debugMode = False, silentMode = False):
 	"""
 	Test all files from module
 	"""
@@ -7,7 +10,7 @@ def testModule(moduleName):
 	from . import tester
 	from . import downloader
 	downloader.updateSilently()
-	results = tester.testModule(moduleName)
+	results = tester.testModule(moduleName, debugMode = debugMode, silentMode = silentMode)
 	try:
 		if __IPYTHON__:
 			import matplotlib.pyplot
@@ -16,7 +19,7 @@ def testModule(moduleName):
 		pass
 	return results
 
-def test(fileName):
+def test(fileName, debugMode = False, silentMode = False):
 	"""
 	Run tests for a single file
 	"""
@@ -25,7 +28,7 @@ def test(fileName):
 	from . import tester
 	from . import downloader
 	downloader.updateSilently()
-	result = tester.test(fileName)
+	result = tester.test(fileName, debugMode = debugMode, silentMode = silentMode)
 	try:
 		if __IPYTHON__:
 			import matplotlib.pyplot
@@ -33,5 +36,3 @@ def test(fileName):
 	except:
 		pass
 	return result
-
-from .downloader import download, update
\ No newline at end of file
